@@ -9,8 +9,7 @@ import (
 )
 
 func TestGroupMilestonesService_ListGroupMilestones(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/5/milestones", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -62,8 +61,7 @@ func TestGroupMilestonesService_ListGroupMilestones(t *testing.T) {
 }
 
 func TestGroupMilestonesService_GetGroupMilestone(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/5/milestones/12", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -113,8 +111,7 @@ func TestGroupMilestonesService_GetGroupMilestone(t *testing.T) {
 }
 
 func TestGroupMilestonesService_CreateGroupMilestone(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/5/milestones", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -164,8 +161,7 @@ func TestGroupMilestonesService_CreateGroupMilestone(t *testing.T) {
 }
 
 func TestGroupMilestonesService_UpdateGroupMilestone(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/5/milestones/12", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPut)
@@ -215,8 +211,7 @@ func TestGroupMilestonesService_UpdateGroupMilestone(t *testing.T) {
 }
 
 func TestGroupMilestonesService_GetGroupMilestoneIssues(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/5/milestones/12/issues", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -335,8 +330,7 @@ func TestGroupMilestonesService_GetGroupMilestoneIssues(t *testing.T) {
 }
 
 func TestGroupMilestonesService_GetGroupMilestoneMergeRequests(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/3/milestones/12/merge_requests", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -409,7 +403,7 @@ func TestGroupMilestonesService_GetGroupMilestoneMergeRequests(t *testing.T) {
 				  "web_url": "https://gitlab.example.com/my-group/my-project/milestones/1"
 				},
 				"merge_when_pipeline_succeeds": true,
-				"merge_status": "can_be_merged",
+				"detailed_merge_status": "mergeable",
 				"sha": "8888888888888888888888888888888888888888",
 				"merge_commit_sha": null,
 				"squash_commit_sha": null,
@@ -486,9 +480,10 @@ func TestGroupMilestonesService_GetGroupMilestoneMergeRequests(t *testing.T) {
 			Title:       "v2.0",
 			Description: "Assumenda aut placeat expedita exercitationem labore sunt enim earum.",
 			State:       "closed",
-			WebURL:      "https://gitlab.example.com/my-group/my-project/milestones/1"},
+			WebURL:      "https://gitlab.example.com/my-group/my-project/milestones/1",
+		},
 		MergeWhenPipelineSucceeds: true,
-		MergeStatus:               "can_be_merged",
+		DetailedMergeStatus:       "mergeable",
 		MergeError:                "",
 		MergedBy: &BasicUser{
 			ID:        87854,
@@ -496,7 +491,8 @@ func TestGroupMilestonesService_GetGroupMilestoneMergeRequests(t *testing.T) {
 			Name:      "Douwe Maan",
 			State:     "active",
 			AvatarURL: "https://gitlab.example.com/uploads/-/system/user/avatar/87854/avatar.png",
-			WebURL:    "https://gitlab.com/DouweM"},
+			WebURL:    "https://gitlab.com/DouweM",
+		},
 		Subscribed:               false,
 		SHA:                      "8888888888888888888888888888888888888888",
 		MergeCommitSHA:           "",
@@ -550,8 +546,7 @@ func TestGroupMilestonesService_GetGroupMilestoneMergeRequests(t *testing.T) {
 }
 
 func TestGroupMilestonesService_GetGroupMilestoneBurndownChartEvents(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/groups/3/milestones/12/burndown_events", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
