@@ -24,8 +24,7 @@ import (
 )
 
 func TestRunPipeline(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/trigger/pipeline", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -34,7 +33,6 @@ func TestRunPipeline(t *testing.T) {
 
 	opt := &RunPipelineTriggerOptions{Ref: String("master")}
 	pipeline, _, err := client.PipelineTriggers.RunPipelineTrigger(1, opt)
-
 	if err != nil {
 		t.Errorf("PipelineTriggers.RunPipelineTrigger returned error: %v", err)
 	}
