@@ -18,6 +18,7 @@ package gitlab
 
 import (
 	"bytes"
+	"encoding/json"
 	"fmt"
 	"net/http"
 	"os"
@@ -25,11 +26,12 @@ import (
 	"strings"
 	"testing"
 	"time"
+
+	"github.com/stretchr/testify/assert"
 )
 
 func TestListProjects(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -58,8 +60,7 @@ func TestListProjects(t *testing.T) {
 }
 
 func TestListUserProjects(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/users/1/projects", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -88,8 +89,7 @@ func TestListUserProjects(t *testing.T) {
 }
 
 func TestListUserStarredProjects(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/users/1/starred_projects", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -118,8 +118,7 @@ func TestListUserStarredProjects(t *testing.T) {
 }
 
 func TestListProjectsUsersByID(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/", func(w http.ResponseWriter, r *http.Request) {
 		testURL(t, r, "/api/v4/projects/1/users?page=2&per_page=3&search=query")
@@ -144,8 +143,7 @@ func TestListProjectsUsersByID(t *testing.T) {
 }
 
 func TestListProjectsUsersByName(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/", func(w http.ResponseWriter, r *http.Request) {
 		testURL(t, r, "/api/v4/projects/namespace%2Fname/users?page=2&per_page=3&search=query")
@@ -170,8 +168,7 @@ func TestListProjectsUsersByName(t *testing.T) {
 }
 
 func TestListProjectsGroupsByID(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/", func(w http.ResponseWriter, r *http.Request) {
 		testURL(t, r, "/api/v4/projects/1/groups?page=2&per_page=3&search=query")
@@ -196,8 +193,7 @@ func TestListProjectsGroupsByID(t *testing.T) {
 }
 
 func TestListProjectsGroupsByName(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/", func(w http.ResponseWriter, r *http.Request) {
 		testURL(t, r, "/api/v4/projects/namespace%2Fname/groups?page=2&per_page=3&search=query")
@@ -222,8 +218,7 @@ func TestListProjectsGroupsByName(t *testing.T) {
 }
 
 func TestListOwnedProjects(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -253,8 +248,7 @@ func TestListOwnedProjects(t *testing.T) {
 }
 
 func TestListStarredProjects(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -284,8 +278,7 @@ func TestListStarredProjects(t *testing.T) {
 }
 
 func TestGetProjectByID(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -306,7 +299,7 @@ func TestGetProjectByID(t *testing.T) {
 		  }`)
 	})
 
-	wantTimestamp := time.Date(2020, 01, 07, 21, 42, 58, 658000000, time.UTC)
+	wantTimestamp := time.Date(2020, 0o1, 0o7, 21, 42, 58, 658000000, time.UTC)
 	want := &Project{
 		ID:                       1,
 		ContainerRegistryEnabled: true,
@@ -329,8 +322,7 @@ func TestGetProjectByID(t *testing.T) {
 }
 
 func TestGetProjectByName(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/", func(w http.ResponseWriter, r *http.Request) {
 		testURL(t, r, "/api/v4/projects/namespace%2Fname")
@@ -350,8 +342,7 @@ func TestGetProjectByName(t *testing.T) {
 }
 
 func TestGetProjectWithOptions(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -394,8 +385,7 @@ func TestGetProjectWithOptions(t *testing.T) {
 }
 
 func TestCreateProject(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -419,8 +409,7 @@ func TestCreateProject(t *testing.T) {
 }
 
 func TestUploadFile(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/uploads", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -445,7 +434,6 @@ func TestUploadFile(t *testing.T) {
 
 	file := bytes.NewBufferString("dummy")
 	projectFile, _, err := client.Projects.UploadFile(1, file, "test.txt")
-
 	if err != nil {
 		t.Fatalf("Projects.UploadFile returns an error: %v", err)
 	}
@@ -456,8 +444,7 @@ func TestUploadFile(t *testing.T) {
 }
 
 func TestUploadFile_Retry(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	tf, _ := os.CreateTemp(os.TempDir(), "test")
 	defer os.Remove(tf.Name())
@@ -490,7 +477,6 @@ func TestUploadFile_Retry(t *testing.T) {
 
 	file := bytes.NewBufferString("dummy")
 	projectFile, _, err := client.Projects.UploadFile(1, file, "test.txt")
-
 	if err != nil {
 		t.Fatalf("Projects.UploadFile returns an error: %v", err)
 	}
@@ -501,8 +487,7 @@ func TestUploadFile_Retry(t *testing.T) {
 }
 
 func TestUploadAvatar(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPut)
@@ -517,15 +502,13 @@ func TestUploadAvatar(t *testing.T) {
 
 	avatar := new(bytes.Buffer)
 	_, _, err := client.Projects.UploadAvatar(1, avatar, "avatar.png")
-
 	if err != nil {
 		t.Fatalf("Projects.UploadAvatar returns an error: %v", err)
 	}
 }
 
 func TestUploadAvatar_Retry(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	isFirstRequest := true
 	mux.HandleFunc("/api/v4/projects/1", func(w http.ResponseWriter, r *http.Request) {
@@ -545,15 +528,13 @@ func TestUploadAvatar_Retry(t *testing.T) {
 
 	avatar := new(bytes.Buffer)
 	_, _, err := client.Projects.UploadAvatar(1, avatar, "avatar.png")
-
 	if err != nil {
 		t.Fatalf("Projects.UploadAvatar returns an error: %v", err)
 	}
 }
 
 func TestListProjectForks(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/", func(w http.ResponseWriter, r *http.Request) {
 		testURL(t, r, "/api/v4/projects/namespace%2Fname/forks?archived=true&order_by=name&page=2&per_page=3&search=query&simple=true&sort=asc&visibility=public")
@@ -582,8 +563,7 @@ func TestListProjectForks(t *testing.T) {
 }
 
 func TestShareProjectWithGroup(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/share", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -601,8 +581,7 @@ func TestShareProjectWithGroup(t *testing.T) {
 }
 
 func TestDeleteSharedProjectFromGroup(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/share/2", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodDelete)
@@ -615,8 +594,7 @@ func TestDeleteSharedProjectFromGroup(t *testing.T) {
 }
 
 func TestGetApprovalConfiguration(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/approvals", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -654,8 +632,7 @@ func TestGetApprovalConfiguration(t *testing.T) {
 }
 
 func TestChangeApprovalConfiguration(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/approvals", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -698,8 +675,7 @@ func TestChangeApprovalConfiguration(t *testing.T) {
 }
 
 func TestChangeAllowedApprovers(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/approvers", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPut)
@@ -755,8 +731,7 @@ func TestChangeAllowedApprovers(t *testing.T) {
 }
 
 func TestForkProject(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	namespaceID := 42
 	name := "myreponame"
@@ -784,8 +759,7 @@ func TestForkProject(t *testing.T) {
 }
 
 func TestGetProjectApprovalRules(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/approval_rules", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -871,7 +845,7 @@ func TestGetProjectApprovalRules(t *testing.T) {
 		]`)
 	})
 
-	approvals, _, err := client.Projects.GetProjectApprovalRules(1)
+	approvals, _, err := client.Projects.GetProjectApprovalRules(1, nil)
 	if err != nil {
 		t.Errorf("Projects.GetProjectApprovalRules returned error: %v", err)
 	}
@@ -960,8 +934,7 @@ func TestGetProjectApprovalRules(t *testing.T) {
 }
 
 func TestGetProjectApprovalRule(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/approval_rules/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -1132,8 +1105,7 @@ func TestGetProjectApprovalRule(t *testing.T) {
 }
 
 func TestCreateProjectApprovalRule(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/approval_rules", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -1310,9 +1282,47 @@ func TestCreateProjectApprovalRule(t *testing.T) {
 	}
 }
 
+func TestGetProjectPullMirrorDetails(t *testing.T) {
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/projects/1/mirror/pull", func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		fmt.Fprint(w, `{
+		  "id": 101486,
+		  "last_error": null,
+		  "last_successful_update_at": "2020-01-06T17:32:02.823Z",
+		  "last_update_at": "2020-01-06T17:32:02.823Z",
+		  "last_update_started_at": "2020-01-06T17:31:55.864Z",
+		  "update_status": "finished",
+		  "url": "https://*****:*****@gitlab.com/gitlab-org/security/gitlab.git"
+		}`)
+	})
+
+	pullMirror, _, err := client.Projects.GetProjectPullMirrorDetails(1)
+	if err != nil {
+		t.Errorf("Projects.GetProjectPullMirrorDetails returned error: %v", err)
+	}
+
+	wantLastSuccessfulUpdateAtTimestamp := time.Date(2020, 0o1, 0o6, 17, 32, 0o2, 823000000, time.UTC)
+	wantLastUpdateAtTimestamp := time.Date(2020, 0o1, 0o6, 17, 32, 0o2, 823000000, time.UTC)
+	wantLastUpdateStartedAtTimestamp := time.Date(2020, 0o1, 0o6, 17, 31, 55, 864000000, time.UTC)
+	want := &ProjectPullMirrorDetails{
+		ID:                     101486,
+		LastError:              "",
+		LastSuccessfulUpdateAt: &wantLastSuccessfulUpdateAtTimestamp,
+		LastUpdateAt:           &wantLastUpdateAtTimestamp,
+		LastUpdateStartedAt:    &wantLastUpdateStartedAtTimestamp,
+		UpdateStatus:           "finished",
+		URL:                    "https://*****:*****@gitlab.com/gitlab-org/security/gitlab.git",
+	}
+
+	if !reflect.DeepEqual(want, pullMirror) {
+		t.Errorf("Projects.GetProjectPullMirrorDetails returned %+v, want %+v", pullMirror, want)
+	}
+}
+
 func TestCreateProjectApprovalRuleEligibleApprovers(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/projects/1/approval_rules", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodPost)
@@ -1354,3 +1364,23 @@ func TestCreateProjectApprovalRuleEligibleApprovers(t *testing.T) {
 		t.Errorf("Projects.CreateProjectApprovalRule returned %+v, want %+v", rule, want)
 	}
 }
+
+func TestProjectModelsOptionalMergeAttribute(t *testing.T) {
+	// Create a `CreateProjectOptions` struct, ensure that merge attribute doesn't serialize
+	jsonString, err := json.Marshal(&CreateProjectOptions{
+		Name: String("testProject"),
+	})
+	if err != nil {
+		t.Fatal("Failed to marshal object", err)
+	}
+	assert.False(t, strings.Contains(string(jsonString), "only_allow_merge_if_all_status_checks_passed"))
+
+	// Test the same thing but for `EditProjectOptions` struct
+	jsonString, err = json.Marshal(&EditProjectOptions{
+		Name: String("testProject"),
+	})
+	if err != nil {
+		t.Fatal("Failed to marshal object", err)
+	}
+	assert.False(t, strings.Contains(string(jsonString), "only_allow_merge_if_all_status_checks_passed"))
+}
