@@ -30,8 +30,7 @@ import (
 )
 
 func TestGetUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := "/api/v4/users/1"
 
@@ -49,7 +48,7 @@ func TestGetUser(t *testing.T) {
 		Name:         "John Smith",
 		State:        "active",
 		WebURL:       "http://localhost:3000/john_smith",
-		CreatedAt:    Time(time.Date(2012, time.May, 23, 8, 00, 58, 0, time.UTC)),
+		CreatedAt:    Time(time.Date(2012, time.May, 23, 8, 0o0, 58, 0, time.UTC)),
 		Bio:          "Bio of John Smith",
 		Location:     "USA",
 		PublicEmail:  "john@example.com",
@@ -65,8 +64,7 @@ func TestGetUser(t *testing.T) {
 }
 
 func TestGetUserAdmin(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := "/api/v4/users/1"
 
@@ -111,7 +109,7 @@ func TestGetUserAdmin(t *testing.T) {
 		CurrentSignInIP:  &currentSignInIP,
 		LastSignInAt:     Time(time.Date(2012, time.June, 1, 11, 41, 1, 0, time.UTC)),
 		LastSignInIP:     &lastSignInIP,
-		ConfirmedAt:      Time(time.Date(2012, time.May, 23, 9, 05, 22, 0, time.UTC)),
+		ConfirmedAt:      Time(time.Date(2012, time.May, 23, 9, 0o5, 22, 0, time.UTC)),
 		TwoFactorEnabled: true,
 		Note:             "DMCA Request: 2018-11-05 | DMCA Violation | Abuse | https://gitlab.zendesk.com/agent/tickets/123",
 		Identities:       []*UserIdentity{{Provider: "github", ExternUID: "2435223452345"}},
@@ -121,8 +119,7 @@ func TestGetUserAdmin(t *testing.T) {
 }
 
 func TestBlockUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/block", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -137,8 +134,7 @@ func TestBlockUser(t *testing.T) {
 }
 
 func TestBlockUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/block", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -153,8 +149,7 @@ func TestBlockUser_UserNotFound(t *testing.T) {
 }
 
 func TestBlockUser_BlockPrevented(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/block", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -169,8 +164,7 @@ func TestBlockUser_BlockPrevented(t *testing.T) {
 }
 
 func TestBlockUser_UnknownError(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/block", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -187,8 +181,7 @@ func TestBlockUser_UnknownError(t *testing.T) {
 }
 
 func TestUnblockUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/unblock", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -203,8 +196,7 @@ func TestUnblockUser(t *testing.T) {
 }
 
 func TestUnblockUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/unblock", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -219,8 +211,7 @@ func TestUnblockUser_UserNotFound(t *testing.T) {
 }
 
 func TestUnblockUser_UnblockPrevented(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/unblock", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -235,8 +226,7 @@ func TestUnblockUser_UnblockPrevented(t *testing.T) {
 }
 
 func TestUnblockUser_UnknownError(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/unblock", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -253,8 +243,7 @@ func TestUnblockUser_UnknownError(t *testing.T) {
 }
 
 func TestBanUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/block", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -269,8 +258,7 @@ func TestBanUser(t *testing.T) {
 }
 
 func TestBanUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/ban", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -285,8 +273,7 @@ func TestBanUser_UserNotFound(t *testing.T) {
 }
 
 func TestBanUser_UnknownError(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/ban", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -303,8 +290,7 @@ func TestBanUser_UnknownError(t *testing.T) {
 }
 
 func TestUnbanUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/unban", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -319,8 +305,7 @@ func TestUnbanUser(t *testing.T) {
 }
 
 func TestUnbanUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/unban", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -335,8 +320,7 @@ func TestUnbanUser_UserNotFound(t *testing.T) {
 }
 
 func TestUnbanUser_UnknownError(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/unban", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -353,8 +337,7 @@ func TestUnbanUser_UnknownError(t *testing.T) {
 }
 
 func TestDeactivateUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/deactivate", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -369,8 +352,7 @@ func TestDeactivateUser(t *testing.T) {
 }
 
 func TestDeactivateUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/deactivate", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -385,8 +367,7 @@ func TestDeactivateUser_UserNotFound(t *testing.T) {
 }
 
 func TestDeactivateUser_DeactivatePrevented(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/deactivate", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -401,8 +382,7 @@ func TestDeactivateUser_DeactivatePrevented(t *testing.T) {
 }
 
 func TestActivateUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/activate", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -417,8 +397,7 @@ func TestActivateUser(t *testing.T) {
 }
 
 func TestActivateUser_ActivatePrevented(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/activate", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -433,8 +412,7 @@ func TestActivateUser_ActivatePrevented(t *testing.T) {
 }
 
 func TestActivateUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/activate", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -449,8 +427,7 @@ func TestActivateUser_UserNotFound(t *testing.T) {
 }
 
 func TestApproveUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/approve", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -465,8 +442,7 @@ func TestApproveUser(t *testing.T) {
 }
 
 func TestApproveUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/approve", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -481,8 +457,7 @@ func TestApproveUser_UserNotFound(t *testing.T) {
 }
 
 func TestApproveUser_ApprovePrevented(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/approve", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -497,8 +472,7 @@ func TestApproveUser_ApprovePrevented(t *testing.T) {
 }
 
 func TestApproveUser_UnknownError(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/approve", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -515,8 +489,7 @@ func TestApproveUser_UnknownError(t *testing.T) {
 }
 
 func TestRejectUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/reject", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -531,8 +504,7 @@ func TestRejectUser(t *testing.T) {
 }
 
 func TestRejectUser_UserNotFound(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/reject", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -547,8 +519,7 @@ func TestRejectUser_UserNotFound(t *testing.T) {
 }
 
 func TestRejectUser_RejectPrevented(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/reject", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -563,8 +534,7 @@ func TestRejectUser_RejectPrevented(t *testing.T) {
 }
 
 func TestRejectUser_Conflict(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/reject", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -579,8 +549,7 @@ func TestRejectUser_Conflict(t *testing.T) {
 }
 
 func TestRejectUser_UnknownError(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/reject", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -597,8 +566,7 @@ func TestRejectUser_UnknownError(t *testing.T) {
 }
 
 func TestGetMemberships(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	path := fmt.Sprintf("/%susers/1/memberships", apiVersionPath)
 	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
@@ -615,9 +583,30 @@ func TestGetMemberships(t *testing.T) {
 	assert.Equal(t, want, memberships)
 }
 
+func TestGetUserAssociationsCount(t *testing.T) {
+	mux, client := setup(t)
+
+	path := "/api/v4/users/1/associations_count"
+
+	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodGet)
+		mustWriteHTTPResponse(t, w, "testdata/get_user_associations_count.json")
+	})
+
+	userAssociationsCount, _, err := client.Users.GetUserAssociationsCount(1)
+	require.NoError(t, err)
+
+	want := &UserAssociationsCount{
+		GroupsCount:        1,
+		ProjectsCount:      2,
+		IssuesCount:        3,
+		MergeRequestsCount: 4,
+	}
+	require.Equal(t, want, userAssociationsCount)
+}
+
 func TestGetSingleSSHKeyForUser(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/users/1/keys/1", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, http.MethodGet)
@@ -627,8 +616,7 @@ func TestGetSingleSSHKeyForUser(t *testing.T) {
 			"title": "Public key",
 			"key": "ssh-rsa AAAA...",
 			"created_at": "2014-08-01T14:47:39.080Z"
-		  }
-`)
+		}`)
 	})
 
 	sshKey, _, err := client.Users.GetSSHKeyForUser(1, 1)
@@ -649,3 +637,48 @@ func TestGetSingleSSHKeyForUser(t *testing.T) {
 		t.Errorf("Users.GetSSHKeyForUser returned %+v, want %+v", sshKey, want)
 	}
 }
+
+func TestDisableUser2FA(t *testing.T) {
+	mux, client := setup(t)
+
+	path := fmt.Sprintf("/%susers/1/disable_two_factor", apiVersionPath)
+	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPatch)
+		w.WriteHeader(http.StatusNoContent)
+	})
+
+	err := client.Users.DisableTwoFactor(1)
+	if err != nil {
+		t.Errorf("Users.DisableTwoFactor returned error: %v", err)
+	}
+}
+
+func TestCreateUserRunner(t *testing.T) {
+	mux, client := setup(t)
+
+	path := fmt.Sprintf("/%suser/runners", apiVersionPath)
+	mux.HandleFunc(path, func(w http.ResponseWriter, r *http.Request) {
+		testMethod(t, r, http.MethodPost)
+		w.WriteHeader(http.StatusCreated)
+		w.Write([]byte(`
+    {
+      "id": 1234,
+      "token": "glrt-1234567890ABCD",
+      "token_expires_at":null
+    }`))
+	})
+
+	createRunnerOpts := &CreateUserRunnerOptions{
+		ProjectID:  Int(1),
+		RunnerType: String("project_type"),
+	}
+
+	response, _, err := client.Users.CreateUserRunner(createRunnerOpts)
+	if err != nil {
+		t.Errorf("Users.CreateUserRunner returned an error: %v", err)
+	}
+
+	require.Equal(t, 1234, response.ID)
+	require.Equal(t, "glrt-1234567890ABCD", response.Token)
+	require.Equal(t, (*time.Time)(nil), response.TokenExpiresAt)
+}
